@@ -1,4 +1,4 @@
-/* $Id: er_fileutils.c,v 1.36 2012/03/14 09:26:56 kbanse Exp $
+/* $Id: er_fileutils.c,v 1.37 2013/02/12 15:37:46 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2012 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: kbanse $
- * $Date: 2012/03/14 09:26:56 $
- * $Revision: 1.36 $
- * $Name: esorex-3_9_6 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/12 15:37:46 $
+ * $Revision: 1.37 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -320,25 +320,16 @@ if (*name != '.')
 
 /* Get the environment variable PWD */
 
-cpp = getenv ("PWD");
-if (cpp != NULL)
-   {
-   len = (int) strlen(cpp);
-   if (len > (PATHSET_MAX-1))
-      {
-      cpl_msg_error (er_func, 
-                     "Buffer overflow in filename '%s' - fatal error",
-                      name);
-      exit (EXIT_FAILURE);
-      }
+cpp = getcwd(str, PATHSET_MAX);
 
-   (void) strcpy (str,cpp);
-   }
-else
-   {
-   cpl_msg_error (er_func, "Env. variable PWD not set - fatal error");
-   exit (EXIT_FAILURE);
-   }
+if (cpp == NULL)
+    {
+    cpl_msg_error(er_func, "Buffer overflow in filename '%s' - fatal error",
+                  name);
+    exit(EXIT_FAILURE);
+    }
+
+len = (int) strlen(cpp);
 
 
 /* Handle the ".." case (add a "/." as the "." replacement) */
