@@ -1,4 +1,4 @@
-/* $Id: er_help.c,v 1.38 2010/05/19 08:21:45 kbanse Exp $
+/* $Id: er_help.c,v 1.41 2013/01/28 10:51:15 cgarcia Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2004 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: kbanse $
- * $Date: 2010/05/19 08:21:45 $
- * $Revision: 1.38 $
- * $Name: esorex-3_9_6 $
+ * $Author: cgarcia $
+ * $Date: 2013/01/28 10:51:15 $
+ * $Revision: 1.41 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,6 +45,7 @@
 #include "er_stringarray.h"
 #include "er_stringutils.h"
 #include "er_fileutils.h"
+#include "er_json.h"
 
 #define SIZE_X    1024 
 
@@ -930,7 +931,8 @@ fprintf(fp, "# End of file\n");
 /**
  * @brief  Generates a default configuration file.
  * @param def_flag	  = 1 for default , = 11 for specific config file
- * @param unit_name       Name of the file to be created (without 
+ * @param context_name    Name of the application context
+ * @param file_name       Name of the file to be created (without 
  *                        extension)
  * @param caller_parlist  List of Parameters from the caller, which
  *                        will govern the behaviour of this function.
@@ -944,11 +946,12 @@ fprintf(fp, "# End of file\n");
 /**********************************************************************/
 
 void er_help_create_config ( int def_flag, 
-                             const char  *unit_name, 
+                             const char  *context_name, 
+                             const char  *file_name, 
                              cpl_parameterlist *caller_parlist, 
                              cpl_parameterlist *config_parlist)
 {
-char file_name[FILEMAX+1];
+char final_file_name[FILEMAX+1];
 char command_str[2*FILEMAX];
 char  *cpp;
 
@@ -961,8 +964,6 @@ FILE *fp = NULL;
 
 int status;
 
-
-
 ER_TRACE(__func__)
 
 
@@ -970,7 +971,7 @@ ER_TRACE(__func__)
 
 if (def_flag == 11)
    {
-   (void) strcpy(file_name,unit_name);
+   (void) strcpy(final_file_name, file_name);
    goto filename_complete;		/* skip the default stuff */
    }
 
@@ -978,40 +979,40 @@ if (def_flag == 11)
 
 cpp = getenv("HOME");
 if (cpp == NULL)
-   (void)strcpy( file_name, "/" );
+   (void)strcpy( final_file_name, "/" );
 else
    {
-   (void) strcpy(file_name,cpp);
-   (void) strcat( file_name, "/" );
+   (void) strcpy(final_file_name,cpp);
+   (void) strcat( final_file_name, "/" );
    }
 # ifndef S_SPLINT_S
-(void)strcat( file_name, GLOBAL_RC_DIR );
+(void)strcat( final_file_name, GLOBAL_RC_DIR );
 # endif
 
-if (fileutils_directory_exists(file_name) == FALSE)
+if (fileutils_directory_exists(final_file_name) == FALSE)
    {
    cpl_msg_warning(er_func, "No global configuration directory exists. "
        "Creating global configuration directory '%s'",
-       file_name);
+       final_file_name);
 
    (void) strcpy(command_str,"mkdir ");
-   (void) strcat(command_str,file_name);
+   (void) strcat(command_str,final_file_name);
    status = system(command_str);
    if(status != 0) cpl_msg_error(er_func, "Error creating directory '%s'",
                                  command_str);
-   if (fileutils_directory_exists(file_name) == FALSE)
+   if (fileutils_directory_exists(final_file_name) == FALSE)
       {
       cpl_msg_error(er_func, "Unable to create global configuration "
-               "directory '%s'\n", file_name );
+               "directory '%s'\n", final_file_name );
       return;
       }
    }
 
 /* Now complete the filename */
 
-(void)strcat( file_name, "/" );
-(void)strcat( file_name, unit_name );
-(void)strcat( file_name, GLOBAL_RC_EXTENSION);
+(void)strcat( final_file_name, "/" );
+(void)strcat( final_file_name, context_name);
+(void)strcat( final_file_name, GLOBAL_RC_EXTENSION);
 
 
 filename_complete:
@@ -1022,15 +1023,15 @@ param = cpl_parameterlist_find(caller_parlist,PACKAGE_RESOURCE ".output-readonly
 flag_readonly = cpl_parameter_get_bool(param);
 
 /* Check for file existence */
-file_exists = fileutils_file_exists(file_name);
+file_exists = fileutils_file_exists(final_file_name);
 
 /* Make a copy of the old configuration file */
 if (file_exists == TRUE)
    {
    (void) strcpy(command_str,"cp ");
-   (void)strcat(command_str,file_name);
+   (void)strcat(command_str,final_file_name);
    (void)strcat(command_str," ");
-   (void)strcat(command_str,file_name);
+   (void)strcat(command_str,final_file_name);
    (void)strcat(command_str, GLOBAL_RC_BACKUP);
    if (system(command_str) != 0)
       {
@@ -1043,30 +1044,44 @@ if (file_exists == TRUE)
    else
       {
       cpl_msg_info(er_func, "Old configuration file copied to '%s%s'",
-                    file_name, GLOBAL_RC_BACKUP);
+              final_file_name, GLOBAL_RC_BACKUP);
       }
    }
 
 /* If we're clear to go, then report it, and being the generation process */
-cpl_msg_info(er_func, "Creating configuration file '%s'", file_name);
+cpl_msg_info(er_func, "Creating configuration file '%s'", final_file_name);
 
-/* Open the file */
-fp = fopen(file_name, "w");
-if (fp == NULL)
-   {
-   cpl_msg_error(er_func, "Unable to create configuration file '%s'",
-       file_name);
-   return;
-   }
+if(strlen(final_file_name)>5 && 
+   strncmp(final_file_name + strlen(final_file_name) - 5, ".json", 5) == 0 )
+{
+    /* We write a JSON format configuration file */
+    cpl_msg_info(cpl_func, "Writing configuration file in JSON format");
+    er_recipe_parameterlist_to_json(config_parlist, context_name,
+                                    final_file_name);
+}
+else
+{
+    /* We write a plain text configuration file */
+    
+    /* Open the file */
+    fp = fopen(final_file_name, "w");
+    if (fp == NULL)
+       {
+       cpl_msg_error(er_func, "Unable to create configuration file '%s'",
+               final_file_name);
+       return;
+       }
 
-/* Generate the header text */
-er_help_create_config_header(fp, file_name);
+    /* Generate the header text */
+    er_help_create_config_header(fp, final_file_name);
 
-/* Generate the actually configuration contents */
-er_help_create_paramlist(fp, config_parlist);
+    /* Generate the actually configuration contents */
+    er_help_create_paramlist(fp, config_parlist);
+
+    /* Close the file and remove the filename string */
+    fclose(fp);
+}
 
-/* Close the file and remove the filename string */
-fclose(fp);
 }
 
 void er_help_free(void)
