@@ -1,4 +1,4 @@
-/* $Id: er_main.c,v 1.87 2012/03/09 17:29:54 kbanse Exp $
+/* $Id: er_main.c,v 1.92 2013/02/14 15:52:57 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2009 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: kbanse $
- * $Date: 2012/03/09 17:29:54 $
- * $Revision: 1.87 $
- * $Name: esorex-3_9_6 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/14 15:52:57 $
+ * $Revision: 1.92 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -61,8 +61,6 @@
 #include "er_fileutils.h"
 #include "er_stringutils.h"
 
-#include "er_prefix.h"
-
 int  MyOS = -1;
 
 static char trace_msg[80];
@@ -176,7 +174,9 @@ p = cpl_parameter_new_value (PACKAGE_RESOURCE ".create-config",
                              " Note that an existing file will be "
                              "overwritten, but a backup file will be "
                              "copied to 'filename.rc.bak' in "
-                             "the same directory.", 
+                             "the same directory. If the filename ends with "
+                             "extension .json then a machine-readable "
+                             "JSON format will be used", 
                              PACKAGE_RESOURCE, "FALSE");
 cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_CLI, "create-config");
 cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
@@ -345,17 +345,17 @@ cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
                          PACKAGE_ENV "_OUTPUT_READONLY");
 cpl_parameterlist_append (param_list, p);
 
-  /*
-   *  paf-config
-   */
+/*
+ *  paf-config
+ */
 
 p = cpl_parameter_new_value (PACKAGE_RESOURCE ".paf-config",
-                           CPL_TYPE_STRING,
-                           "Configuration file for creation of PAF files.",
-                           PACKAGE_RESOURCE, "");
+                         CPL_TYPE_STRING,
+                         "Configuration file for creation of PAF files.",
+                         PACKAGE_RESOURCE, "");
 cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_CLI, "paf-config");
 cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
-                       PACKAGE_ENV "_PAF_CONFIG");
+                     PACKAGE_ENV "_PAF_CONFIG");
 cpl_parameterlist_append (param_list, p);
 
   /*
@@ -378,6 +378,22 @@ cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
                          PACKAGE_ENV "_PARAMS");
 cpl_parameterlist_append (param_list, p);
 
+/*
+ *  products-sof
+ */
+
+p = cpl_parameter_new_value (PACKAGE_RESOURCE ".products-sof",
+                         CPL_TYPE_STRING,
+                         "Output file which contains the FITS files "
+                         "created by the recipe. If the filename ends with "
+                         "extension .json then a machine-readable JSON format"
+                         "will be used",
+                         PACKAGE_RESOURCE, "");
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_CLI, "products-sof");
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
+                     PACKAGE_ENV "_PRODUCTS_SOF");
+cpl_parameterlist_append (param_list, p);
+
   /*
    *  recipes
    */
@@ -625,6 +641,7 @@ cpl_init (init_flag);                    /* also does cpl_msg_init() stuff */
 
 cpl_msg_set_domain (PACKAGE);
 cpl_msg_set_time_off ();
+cpl_msg_set_threadid_off ();
 cpl_msg_set_domain_on ();
 cpl_msg_set_component_off ();
 
@@ -719,7 +736,10 @@ else
 
    (void) strcpy(save_name,conf_file_global);
 
-   (void) strcpy(new_name,ESOREX_PREFIX);	/* replace by .rc name in --prefix dir */
+   /* The SYSCONFDIR is defind with -DSYSCONFDIR="\"@sysconfdir@\"" in the
+    * Makefile.am, while @sysconfdir@ is substituted partly by configure and
+    * partly by make */
+   (void) strcpy(new_name, SYSCONFDIR"/");	
    (void) strcat(new_name, GLOBAL_RC_NAME);
    (void) strcat(new_name, GLOBAL_RC_EXTENSION);
 
@@ -751,13 +771,6 @@ else
 
 er_init_parameters (caller_parameter_list);
 
-if (argc == 1)		/* entering just Esorex yields the library versions */
-   {
-   cdescr = cpl_get_description(CPL_DESCRIPTION_DEFAULT);
-   (void) printf("\nLibraries used: %s\n\n",cdescr);
-   goto clean_up;
-   }
-
 cdescr = cpl_get_description(CPL_DESCRIPTION_DEFAULT);
 
 if ((argc == 2) && ((int)strcmp(argv[1],"--V") == 0)) 
@@ -783,15 +796,22 @@ ER_TRACEX (trace_msg)
 
 /* Process Plugin */
 
-if (e_code == 0)
-   {
-   e_code = plugin_process_plugin (caller_parameter_list,
-                                   plugin_name, set_of_frames_filenames,
-                                   date_str,argc, argv);
- 
-   (void) sprintf(trace_msg,"plugin_process_plugin returned %d",e_code); 
-   ER_TRACEX(trace_msg)
-   }
+if (e_code == 0 && plugin_name[0] != '\0')
+{
+    e_code = plugin_process_plugin (caller_parameter_list,
+            plugin_name, set_of_frames_filenames,
+            date_str,argc, argv);
+
+    (void) sprintf(trace_msg,"plugin_process_plugin returned %d",e_code); 
+    ER_TRACEX(trace_msg)
+}
+else if(e_code !=-99999)  /* entering just Esorex yields the library versions */
+{
+    cdescr = cpl_get_description(CPL_DESCRIPTION_DEFAULT);
+    (void) printf("\nLibraries used: %s\n\n",cdescr);
+    goto clean_up;
+}
+
 
 
 
@@ -810,7 +830,18 @@ if (msg_level == CPL_MSG_DEBUG)
       }
    }
 
-if (lt_dlexit () != 0) cpl_msg_error (fn, "Unable to deinitialize ltdl");
+p = cpl_parameterlist_find (caller_parameter_list,
+                            PACKAGE_RESOURCE ".unload-plugin");
+
+if (cpl_parameter_get_bool(p) != 0) {
+    if (lt_dlexit () != 0) {
+        cpl_msg_error (fn, "Unable to deinitialize ltdl");
+    }
+}
+else {
+    cpl_msg_warning(fn, "unloading of plugins is inhibited by program "
+                    "option 'unload-plugin'!");
+}
 
 p = cpl_parameterlist_find (caller_parameter_list, PACKAGE_RESOURCE ".mem-check");
 flag_mem_check = cpl_parameter_get_bool (p);
