@@ -1,4 +1,4 @@
-/* $Id: er_paf.c,v 1.17 2010/08/11 08:34:54 cgarcia Exp $
+/* $Id: er_paf.c,v 1.18 2012/12/13 18:40:38 cgarcia Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2004 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: cgarcia $
- * $Date: 2010/08/11 08:34:54 $
- * $Revision: 1.17 $
- * $Name: esorex-3_9_6 $
+ * $Date: 2012/12/13 18:40:38 $
+ * $Revision: 1.18 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -335,7 +335,7 @@ struct er_paf_config_item * er_paf_get_matching_item
 		REG_EXTENDED|REG_NOSUB);
 	if(regstatus)
 	    {
-	    cpl_msg_error(er_func, "Bad formatted PRO CATG regular expresion");
+	    cpl_msg_error(er_func, "Bad formatted PRO CATG regular expression");
 	    cpl_error_set(er_func, CPL_ERROR_ILLEGAL_INPUT);
 	    cpl_msg_indent_less();
 	    regfree(&pattern);
