@@ -1,4 +1,4 @@
-/* $Id: er_params.c,v 1.62 2012/02/23 13:36:02 kbanse Exp $
+/* $Id: er_params.c,v 1.64 2013/01/03 17:55:39 cgarcia Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2009 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: kbanse $
- * $Date: 2012/02/23 13:36:02 $
- * $Revision: 1.62 $
- * $Name: esorex-3_9_6 $
+ * $Author: cgarcia $
+ * $Date: 2013/01/03 17:55:39 $
+ * $Revision: 1.64 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -887,6 +887,7 @@ const char *val_log_file = NULL;
 const char *val_log_dir = NULL;
 const char *val_log_level = NULL;
 const char *val_paf_config = NULL;
+const char *val_products_sof = NULL;
 
 char *val_plugin_dir = NULL;
 char **val_recipe_dirs = NULL;
@@ -913,6 +914,7 @@ int f_val_config = 0,
     f_val_log_dir = 0,
     f_val_log_level = 0,
     f_val_paf_config = 0,
+    f_val_products_sof = 0,
     f_continue = 1;
 
 
@@ -1107,6 +1109,19 @@ else
    f_val_paf_config = 1;
 
 
+p = cpl_parameterlist_find (param_list, PACKAGE_RESOURCE ".products-sof");
+if (cpl_parameter_get_default_flag (p))
+   {
+   val_products_sof = cpl_parameter_get_string (p);
+   ForceNull(val_products_sof )
+   if (val_products_sof  != NULL)
+       {
+       f_val_products_sof = fileutils_file_exists (val_products_sof );
+       }
+   }
+else
+   f_val_products_sof = 1;
+
 /* Now deal with the parameters individually */
 
 /* esorex.caller.msg-level */
@@ -1383,14 +1398,16 @@ if ((f_continue != 0) && (f_val_create != 0))
          saved_name = malloc(k);
          (void) strcpy(saved_name,val_create);
          cpl_parameter_set_string (param, "FALSE");
-         er_help_create_config (f_val_create,saved_name, param_list, param_list);
+         er_help_create_config (f_val_create,plugin_name, saved_name,
+                                param_list, param_list);
          }
       else
          {
          saved_name = malloc(8);
          (void) strcpy(saved_name,"TRUE");
          cpl_parameter_set_string (param, "FALSE");
-         er_help_create_config (f_val_create,PACKAGE, param_list, param_list);
+         er_help_create_config (f_val_create,PACKAGE, "",
+                                param_list, param_list);
          }
 
       cpl_parameter_set_string (param, saved_name);
@@ -1421,7 +1438,25 @@ if ((f_continue != 0) && (f_val_paf_config == 0))
    goto clean_up;
    }
 
-  /*
+/*
+ *  esorex.caller.products-sof
+ */
+
+if ((f_continue != 0) && (f_val_products_sof == 0))
+   {
+    if (val_products_sof == NULL)
+       {
+       cpl_msg_error (er_func, "'--products-sof' was specified, but no argument given. "
+                      "Check that there is only an equals sign "
+                      "(\"=\") between the '--products-sof' and the directory path, and "
+                      "that all environment variables are resolved.");
+       f_continue = 0;
+       err = -1;
+       goto clean_up;
+       }
+    }
+
+/*
    * Clean-up
    */
 
