@@ -1,4 +1,4 @@
-/* $Id: er_paramutils.c,v 1.41 2011/04/06 09:35:34 kbanse Exp $
+/* $Id: er_paramutils.c,v 1.42 2013/02/19 15:54:03 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2004 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: kbanse $
- * $Date: 2011/04/06 09:35:34 $
- * $Revision: 1.41 $
- * $Name: esorex-3_9_6 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/19 15:54:03 $
+ * $Revision: 1.42 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -731,7 +731,7 @@ switch (pclass)
             (void) strcat (tmp, " to ");
             (void) strcat (tmp, er_strutils_dblstr (cpl_parameter_get_range_max_double (p)));
             (void) strcat (tmp, ".\n");
-            cpl_msg_error (er_func, tmp);
+            cpl_msg_error (er_func, "%s", tmp);
 
             cpl_free(tmp);
             return -1;
