@@ -1,4 +1,4 @@
-/* $Id: er_plugin.c,v 1.109 2012/05/08 08:10:27 rpalsa Exp $
+/* $Id: er_plugin.c,v 1.115 2013/02/19 15:54:36 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2012 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/05/08 08:10:27 $
- * $Revision: 1.109 $
- * $Name: esorex-3_9_6 $
+ * $Date: 2013/02/19 15:54:36 $
+ * $Revision: 1.115 $
+ * $Name: esorex-3_10 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,6 +56,7 @@
 #include "er_plugin.h"
 #include "er_pluginlist.h"
 #include "er_paf.h"
+#include "er_json.h"
 #include "er_stringutils.h"
 
 static char trace_msg[80];
@@ -366,7 +367,7 @@ while( fgets (line, (SIZE_C-1), fp))
             if (wer != 0)
                {
                (void) snprintf(estr,(size_t)238,"Expansion of %s failed...",xpath);
-               cpl_msg_error (er_func, estr);
+               cpl_msg_error (er_func, "%s", estr);
                goto dealloc;
                }
             }
@@ -949,6 +950,10 @@ const char *cdescr;
 
 const char *val_paf_config;
 
+const char *val_products_sof;
+
+const char *val_create = NULL;
+
 char **val_recipe_dirs = NULL,
      *log_file_name_full = NULL;
 
@@ -957,7 +962,7 @@ char *cptr,
      *plugin_conf_file_local=NULL,
      library_path[MAXSTRLENCONF];
 
-char *val_create = NULL, *help_str = NULL;
+char *help_str = NULL;
 
 int e_code = 0, e_code2 = 0, i = 0, ii = 0;
 int countr, n, sz;
@@ -1319,12 +1324,14 @@ if (flag_plugin_found != 0)			/*  = TRUE */
       }
    if (flag_create_config == 11)
       {
-      er_help_create_config (flag_create_config,val_create, caller_parameters, trecipe->parameters);
+      er_help_create_config (flag_create_config, plugin_name, val_create,
+                             caller_parameters, trecipe->parameters);
       e_code = -99999;
       }
    else if (flag_create_config == 1)
       {
-      er_help_create_config (flag_create_config, plugin_name, caller_parameters, trecipe->parameters);
+      er_help_create_config (flag_create_config, plugin_name, NULL, 
+                             caller_parameters, trecipe->parameters);
       e_code = -99999;
       }
 
@@ -1544,16 +1551,63 @@ if (flag_plugin_found != 0)			/*  = TRUE */
           }
        }
 
+   /* Write output sof */
+   p = cpl_parameterlist_find (caller_parameters,
+                               PACKAGE_RESOURCE ".products-sof");
+   val_products_sof = cpl_parameter_get_string (p);
+   ForceNull(val_products_sof)
+   if(val_products_sof != NULL)
+       {
+       if (e_code == 0)    /* successful execution of recipe and product move*/
+          {
+               cpl_frameset * output_frames;
+               cpl_frame    * frame;
+               output_frames = cpl_frameset_new();
+               frame = cpl_frameset_get_first (trecipe->frames);
+               while (frame != NULL)
+               {
+                   if (cpl_frame_get_group (frame) == CPL_FRAME_GROUP_PRODUCT)
+                   {
+                       cpl_frameset_insert(output_frames, 
+                                           cpl_frame_duplicate(frame));
+                   }
+                   frame = cpl_frameset_get_next(trecipe->frames);
+               }
+               
+               if(strlen(val_products_sof)>5 && 
+                       strncmp(val_products_sof + strlen(val_products_sof) - 5,
+                               ".json", 5) == 0 )
+                   e_code = er_frameset_to_json(output_frames, val_products_sof);
+               else
+                   e_code = er_frameset_to_text(output_frames, val_products_sof);
+
+               cpl_frameset_delete(output_frames);
+               if (e_code != 0)
+                  {
+                  cpl_msg_error (er_func,"Cannot create output sof file, "
+                                 "status = %d",
+                                 e_code);
+                  }
+          }
+       else
+          {
+          cpl_msg_warning (er_func,"Writing of output sof omitted"
+                                   " due to previous errors");
+          }
+       }
 
    /* Run Plugin Deinitialisation...  */
 
   plugin_deinit:
+
+#if 0
    if (f_val_unload_plugin == 0) 	/* we want to keep all memory */
       {
       cpl_msg_info(er_func,
           "The plugin info will not be removed after execution!");
       goto final_end;			/* as it is for debugging! */
       }
+#endif
 
    plugin_func_deinit = cpl_plugin_get_deinit ((cpl_plugin *) trecipe);
 
@@ -1699,7 +1753,9 @@ if (tplugin != NULL) cpl_plugin_delete (tplugin);
 
 #ifdef STATIC_LINK
 #else
-if (module != NULL) lt_dlclose (module);
+if ((module != NULL) && (f_val_unload_plugin != 0)) {
+    lt_dlclose (module);
+}
 #endif
 
 if (t2recipe != NULL)
